import { SQS } from 'aws-sdk';
import { Consumer } from 'sqs-consumer';
import { DefaultTaskContext } from './context';
import { GetConsumerInput, GetConsumersInput, SubmitAllTasksResponse, SubmitTaskInput, SubmitTaskResponse, TaskClient } from './client';
import { OperationConfiguration, OperationName, QueueConfiguration, QueueName } from './types';
export interface ClientConfiguration {
    defaultQueue: QueueConfiguration;
    /**
     * Optionally specify additional queues aside from the requisite default queue
     */
    queues?: Record<QueueName, QueueConfiguration>;
    /**
     * The SQS client provided to queues upon initialization
     *
     * Defaults to `new AWS.SQS()`
     */
    sqsClient?: SQS;
}
/**
 * Handles configuring queues, registering operations, and enqueueing/dequeueing tasks
 * for processing
 */
export declare class AsyncTasksClient<TContext = DefaultTaskContext> implements TaskClient<TContext> {
    private sqsClient;
    private queues;
    private routes;
    constructor(config: ClientConfiguration);
    readonly registeredOperations: OperationName[];
    readonly queueNames: QueueName[];
    /**
     * Register an operation type with the asyncTask client
     *
     * Operations must have a name, a validation function, and a handler function and may
     * specify a queue on which jobs should be submitted by default
     *
     * @throws {QueueNotRegistered} the queueId specified is not registered
     */
    registerOperation<TPayload>(input: OperationConfiguration<TPayload, TContext>): void;
    /**
     * Enqueues a task for a specified operation
     *
     * * Tasks must specify an operationName and a payload that can be serialized to JSON.
     * * The payload will be validated against the validation function provided when the
     *   operation was registered
     *
     * @throws {OperationNotRegistered} the operationName has not been configured
     * @throws {InvalidPayloadError} the provided payload did not pass validation
     * @throws {QueueNotRegistered} the specified queue is not configured
     * @returns the SQS MessageId and a unique taskId generated on our side
     */
    submitTask<T>(input: SubmitTaskInput<T>): Promise<SubmitTaskResponse>;
    submitAllTasks<T = any>(input: SubmitTaskInput<T>[]): Promise<SubmitAllTasksResponse>;
    /**
     * Returns a configured SQS Consumer for the provided queueName and context provider
     * @param input At a minimum the contextProvider and queueName
     */
    generateConsumer(input: GetConsumerInput<TContext>): Consumer;
    generateConsumers(input: GetConsumersInput<TContext>): Record<QueueName, Consumer>;
    private _routeToTask;
}
